==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Test/Gui/Resources/translations/Test_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ca" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UniTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Fallades i errors</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Descripció</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Inici</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt + S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Ajuda</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;Sobre</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt + A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>Tan&amp;ca</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Inactiu</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Progrés</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation type="unfinished">&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Restant:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Errors:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Fallades:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Executa:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Test</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Seleccioni el nom del test:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Ajuda</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>Sobre FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer

 FreeCAD UnitTest és part de FreeCAD i permet escriure tests unitaris per els moduls propis.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Introduïu el nom d'un objecte cridable, quan es cridi retornarà un TestCase. Clicar 'Començar' i s'executarà el test d'aquest procediment. 

Fer doble clic a un error a la vista en arbre per veure més informació sobre ell, incloent-hi el rastreig de pila.</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Test/Gui/Resources/translations/Test_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ca" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Fallades i errors</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Descripció</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Inici</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt + S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Ajuda</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;Sobre</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt + A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>Tan&amp;ca</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Inactiu</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Progrés</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation type="unfinished">&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Restant:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Errors:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Fallades:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Executa:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Test</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Seleccioni el nom del test:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Ajuda</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>Sobre FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer

 FreeCAD UnitTest és part de FreeCAD i permet escriure tests unitaris per els moduls propis.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Introduïu el nom d'un objecte cridable que quan es cridi retorni un TestCase. Feu clic a 'Començar' i s'executarà el test anteriorment produït. 

Feu doble clic a un error a la vista d'arbre per veure'n més informació, incloent-hi la traça de pila.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Introduïu el nom d'un objecte cridable que quan es cridi retorni un TestCase.
Feu clic a 'Començar' i s'executarà el test anteriorment produït. 

Feu doble clic a un error a la vista d'arbre per veure'n més informació, incloent-hi la traça de pila.</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD UnitTest és part de FreeCAD i permet escriure Unit Tests per a mòduls propis.</translation>
    </message>
  </context>
</TS>
